pub struct MockSecurityTaskApi {
SecurityTaskApi_expectations: MockSecurityTaskApi_SecurityTaskApi,
}Fields
SecurityTaskApi_expectations: MockSecurityTaskApi_SecurityTaskApiImplementations
Sourceimpl MockSecurityTaskApi
impl MockSecurityTaskApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockSecurityTaskApi
impl MockSecurityTaskApi
Sourcepub fn expect_bulk_create_tasks(&mut self) -> &mut Expectation
pub fn expect_bulk_create_tasks(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_create_tasks method
Sourcepub fn expect_complete(&mut self) -> &mut Expectation
pub fn expect_complete(&mut self) -> &mut Expectation
Create an Expectation for mocking the complete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_task_metrics_for_organization(&mut self) -> &mut Expectation
pub fn expect_get_task_metrics_for_organization(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_task_metrics_for_organization method
Sourcepub fn expect_list_for_organization(&mut self) -> &mut Expectation
pub fn expect_list_for_organization(&mut self) -> &mut Expectation
Create an Expectation for mocking the list_for_organization method